==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/pl.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Pamięć nie dostępna",
    "Storage invalid" : "Pamięć nieprawidłowa",
    "Unknown error" : "Nieznany błąd",
    "Could not move %s - File with this name already exists" : "Nie można było przenieść %s - Plik o takiej nazwie już istnieje",
    "Could not move %s" : "Nie można było przenieść %s",
    "Permission denied" : "Dostęp zabroniony",
    "The target folder has been moved or deleted." : "Folder docelowy został przeniesiony lub usunięty",
    "The name %s is already used in the folder %s. Please choose a different name." : "Nazwa %s jest już używana w folderze %s. Proszę wybrać inną nazwę.",
    "Error when creating the file" : "Błąd przy tworzeniu pliku",
    "Error when creating the folder" : "Błąd przy tworzeniu folderu",
    "Unable to set upload directory." : "Nie można ustawić katalog wczytywania.",
    "Invalid Token" : "Nieprawidłowy Token",
    "No file was uploaded. Unknown error" : "Żaden plik nie został załadowany. Nieznany błąd",
    "There is no error, the file uploaded with success" : "Nie było błędów, plik wysłano poprawnie.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Wgrany plik przekracza wartość upload_max_filesize zdefiniowaną w php.ini: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Wysłany plik przekracza wielkość dyrektywy MAX_FILE_SIZE określonej w formularzu HTML",
    "The uploaded file was only partially uploaded" : "Załadowany plik został wysłany tylko częściowo.",
    "No file was uploaded" : "Nie wysłano żadnego pliku",
    "Missing a temporary folder" : "Brak folderu tymczasowego",
    "Failed to write to disk" : "Błąd zapisu na dysk",
    "Not enough storage available" : "Za mało dostępnego miejsca",
    "Upload failed. Could not find uploaded file" : "Nieudane przesłanie. Nie można znaleźć przesyłanego pliku",
    "Upload failed. Could not get file info." : "Nieudane przesłanie. Nie można pobrać informacji o pliku.",
    "Invalid directory." : "Zła ścieżka.",
    "Files" : "Pliki",
    "All files" : "Wszystkie pliki",
    "Favorites" : "Ulubione",
    "Home" : "Dom",
    "Close" : "Zamknij",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nie można przesłać {filename} być może jest katalogiem lub posiada 0 bajtów",
    "Total file size {size1} exceeds upload limit {size2}" : "Całkowity rozmiar {size1} przekracza limit uploadu {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Brak wolnej przestrzeni, przesyłasz {size1} a pozostało tylko {size2}",
    "Upload cancelled." : "Wczytywanie anulowane.",
    "Could not get result from server." : "Nie można uzyskać wyniku z serwera.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Wysyłanie pliku jest w toku. Jeśli opuścisz tę stronę, wysyłanie zostanie przerwane.",
    "Actions" : "Akcje",
    "Download" : "Pobierz",
    "Rename" : "Zmień nazwę",
    "Delete" : "Usuń",
    "Details" : "Szczegóły",
    "Select" : "Wybierz",
    "Pending" : "Oczekujące",
    "Unable to determine date" : "Nie można ustalić daty",
    "Error moving file." : "Błąd podczas przenoszenia pliku.",
    "Error moving file" : "Błąd prz przenoszeniu pliku",
    "Error" : "Błąd",
    "{new_name} already exists" : "{new_name} już istnieje",
    "Could not rename file" : "Nie można zmienić nazwy pliku",
    "Could not create file" : "Nie można utworzyć pliku",
    "Could not create folder" : "Nie można utworzyć folderu",
    "Error deleting file." : "Błąd podczas usuwania pliku",
    "No entries in this folder match '{filter}'" : "Brak wyników pasujących do '{filter}'",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Modyfikacja",
    "_%n folder_::_%n folders_" : ["%n katalog","%n katalogi","%n katalogów"],
    "_%n file_::_%n files_" : ["%n plik","%n pliki","%n plików"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wczytywania lub tworzenia plików w tym miejscu",
    "_Uploading %n file_::_Uploading %n files_" : ["Wysyłanie %n pliku","Wysyłanie %n plików","Wysyłanie %n plików"],
    "New" : "Nowy",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Brak wolnego miejsca {owner}, pliki nie mogą zostać zaktualizowane lub synchronizowane! ",
    "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Pliki nie mogą zostać zaktualizowane lub zsynchronizowane!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Miejsce dla {owner} jest na wyczerpaniu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Twój magazyn jest prawie pełny ({usedSpacePercent}%)",
    "Favorited" : "Ulubione",
    "Favorite" : "Ulubione",
    "Upload" : "Wyślij",
    "Text file" : "Plik tekstowy",
    "Folder" : "Folder",
    "New folder" : "Nowy folder",
    "A new file or folder has been <strong>created</strong>" : "Nowy plik lub folder został <strong>utworzony</strong>",
    "A file or folder has been <strong>changed</strong>" : "Plik lub folder został <strong>zmieniony</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Plik lub folder został <strong>usunięty</strong>",
    "A file or folder has been <strong>restored</strong>" : "Plik lub folder został <strong>przywrócy</strong>",
    "You created %1$s" : "Utworzyłeś %1$s",
    "%2$s created %1$s" : "%2$s utworzył %1$s",
    "%1$s was created in a public folder" : "%1$s został utworzony w folderze publicznym",
    "You changed %1$s" : "Zmieniłeś %1$s",
    "%2$s changed %1$s" : "%2$s zmienił %1$s",
    "You deleted %1$s" : "Usunąłeś %1$s",
    "%2$s deleted %1$s" : "%2$s usunął %1$s",
    "You restored %1$s" : "Przywróciłeś %1$s",
    "%2$s restored %1$s" : "%2$s przywrócił %1$s",
    "%s could not be renamed as it has been deleted" : "%s nie może mieć zmienionej nazwy, ponieważ został usunięty",
    "%s could not be renamed" : "%s nie można zmienić nazwy",
    "Upload (max. %s)" : "Wysyłka (max. %s)",
    "File handling" : "Zarządzanie plikami",
    "Maximum upload size" : "Maksymalny rozmiar wysyłanego pliku",
    "max. possible: " : "maks. możliwy:",
    "Save" : "Zapisz",
    "Settings" : "Ustawienia",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Użyj tego adresu do <a href=\"%s\" target=\"_blank\">dostępu do twoich plików przez WebDAV</a>",
    "Cancel upload" : "Anuluj wysyłanie",
    "No entries found in this folder" : "Brak wpisów w tym folderze",
    "Select all" : "Wybierz wszystko",
    "Upload too large" : "Ładowany plik jest za duży",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz przesłać, przekraczają maksymalną dopuszczalną wielkość.",
    "Files are being scanned, please wait." : "Skanowanie plików, proszę czekać.",
    "Currently scanning" : "Aktualnie skanowane"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/pl.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Pamięć nie dostępna",
    "Storage invalid" : "Pamięć nieprawidłowa",
    "Unknown error" : "Nieznany błąd",
    "Unable to set upload directory." : "Nie można ustawić katalog wczytywania.",
    "Invalid Token" : "Nieprawidłowy Token",
    "No file was uploaded. Unknown error" : "Żaden plik nie został załadowany. Nieznany błąd",
    "There is no error, the file uploaded with success" : "Nie było błędów, plik wysłano poprawnie.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Wgrany plik przekracza wartość upload_max_filesize zdefiniowaną w php.ini: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Wysłany plik przekracza wielkość dyrektywy MAX_FILE_SIZE określonej w formularzu HTML",
    "The uploaded file was only partially uploaded" : "Załadowany plik został wysłany tylko częściowo.",
    "No file was uploaded" : "Nie wysłano żadnego pliku",
    "Missing a temporary folder" : "Brak folderu tymczasowego",
    "Failed to write to disk" : "Błąd zapisu na dysk",
    "Not enough storage available" : "Za mało dostępnego miejsca",
    "The target folder has been moved or deleted." : "Folder docelowy został przeniesiony lub usunięty",
    "Upload failed. Could not find uploaded file" : "Nieudane przesłanie. Nie można znaleźć przesyłanego pliku",
    "Upload failed. Could not get file info." : "Nieudane przesłanie. Nie można pobrać informacji o pliku.",
    "Invalid directory." : "Zła ścieżka.",
    "Files" : "Pliki",
    "All files" : "Wszystkie pliki",
    "Favorites" : "Ulubione",
    "Home" : "Dom",
    "Close" : "Zamknij",
    "Upload cancelled." : "Wczytywanie anulowane.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nie można przesłać {filename} być może jest katalogiem lub posiada 0 bajtów",
    "Total file size {size1} exceeds upload limit {size2}" : "Całkowity rozmiar {size1} przekracza limit uploadu {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Brak wolnej przestrzeni, przesyłasz {size1} a pozostało tylko {size2}",
    "Could not get result from server." : "Nie można uzyskać wyniku z serwera.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Wysyłanie pliku jest w toku. Jeśli opuścisz tę stronę, wysyłanie zostanie przerwane.",
    "Actions" : "Akcje",
    "Download" : "Pobierz",
    "Rename" : "Zmień nazwę",
    "Delete" : "Usuń",
    "Disconnect storage" : "Odłącz magazyn",
    "Unshare" : "Zatrzymaj współdzielenie",
    "Details" : "Szczegóły",
    "Select" : "Wybierz",
    "Pending" : "Oczekujące",
    "Unable to determine date" : "Nie można ustalić daty",
    "No entries in this folder match '{filter}'" : "Brak wyników pasujących do '{filter}'",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Modyfikacja",
    "_%n folder_::_%n folders_" : ["%n katalog","%n katalogi","%n katalogów"],
    "_%n file_::_%n files_" : ["%n plik","%n pliki","%n plików"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wczytywania lub tworzenia plików w tym miejscu",
    "_Uploading %n file_::_Uploading %n files_" : ["Wysyłanie %n pliku","Wysyłanie %n plików","Wysyłanie %n plików"],
    "New" : "Nowy",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Brak wolnego miejsca {owner}, pliki nie mogą zostać zaktualizowane lub synchronizowane! ",
    "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Pliki nie mogą zostać zaktualizowane lub zsynchronizowane!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Miejsce dla {owner} jest na wyczerpaniu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Twój magazyn jest prawie pełny ({usedSpacePercent}%)",
    "Favorited" : "Ulubione",
    "Favorite" : "Ulubione",
    "Folder" : "Folder",
    "New folder" : "Nowy folder",
    "Upload" : "Wyślij",
    "A new file or folder has been <strong>created</strong>" : "Nowy plik lub folder został <strong>utworzony</strong>",
    "A file or folder has been <strong>changed</strong>" : "Plik lub folder został <strong>zmieniony</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Plik lub folder został <strong>usunięty</strong>",
    "A file or folder has been <strong>restored</strong>" : "Plik lub folder został <strong>przywrócy</strong>",
    "You created %1$s" : "Utworzyłeś %1$s",
    "%2$s created %1$s" : "%2$s utworzył %1$s",
    "%1$s was created in a public folder" : "%1$s został utworzony w folderze publicznym",
    "You changed %1$s" : "Zmieniłeś %1$s",
    "%2$s changed %1$s" : "%2$s zmienił %1$s",
    "You deleted %1$s" : "Usunąłeś %1$s",
    "%2$s deleted %1$s" : "%2$s usunął %1$s",
    "You restored %1$s" : "Przywróciłeś %1$s",
    "%2$s restored %1$s" : "%2$s przywrócił %1$s",
    "Upload (max. %s)" : "Wysyłka (max. %s)",
    "File handling" : "Zarządzanie plikami",
    "Maximum upload size" : "Maksymalny rozmiar wysyłanego pliku",
    "max. possible: " : "maks. możliwy:",
    "Save" : "Zapisz",
    "Settings" : "Ustawienia",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Użyj tego adresu do <a href=\"%s\" target=\"_blank\">dostępu do twoich plików przez WebDAV</a>",
    "Cancel upload" : "Anuluj wysyłanie",
    "No entries found in this folder" : "Brak wpisów w tym folderze",
    "Select all" : "Wybierz wszystko",
    "Upload too large" : "Ładowany plik jest za duży",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz przesłać, przekraczają maksymalną dopuszczalną wielkość.",
    "Text file" : "Plik tekstowy"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
